@@ -1,3 +1,3 @@
-from .plotmath import plot, show, savefig, histogram
+from .plotmath import plot, show, savefig, histogram, plot_polygon
 
 __all__ = ["plot", "savefig", "show", "histogram", "plot_polygon"]
